@@ -112,6 +112,9 @@ __PACKAGE__->create_children(qw/
     Net::ISC::DHCPd::Config::OptionSpace
     Net::ISC::DHCPd::Config::Option
     Net::ISC::DHCPd::Config::Include
+    Net::ISC::DHCPd::Config::Key
+    Net::ISC::DHCPd::Config::Group
+    Net::ISC::DHCPd::Config::Block
     Net::ISC::DHCPd::Config::KeyValue
 /);
 
